summaryrefslogtreecommitdiffstats
path: root/konversation/src/nicksonline.h
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/nicksonline.h')
-rw-r--r--konversation/src/nicksonline.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/konversation/src/nicksonline.h b/konversation/src/nicksonline.h
index 17ace06..d0b14a0 100644
--- a/konversation/src/nicksonline.h
+++ b/konversation/src/nicksonline.h
@@ -61,7 +61,7 @@ class NicksOnline : public ChatWindow
nsHasAddress = 2 // Nick has an associated addressbook entry.
};
- explicit NicksOnline(TQWidget* tqparent);
+ explicit NicksOnline(TQWidget* parent);
~NicksOnline();
// These are here for the benefit of NicksOnlineTooltip.
@@ -135,20 +135,20 @@ class NicksOnline : public ChatWindow
private:
/**
* Returns the named child of tqparent item in a NicksOnlineItem
* @param tqparent Pointer to a NicksOnlineItem.
* @param name The name in the desired child TQListViewItem, must be in column 0.
* @param type The type of entry to be found
* @return Pointer to the child TQListViewItem or 0 if not found.
*/
- TQListViewItem* findItemChild(const TQListViewItem* tqparent, const TQString& name, NicksOnlineItem::NickListViewColumn type);
+ TQListViewItem* findItemChild(const TQListViewItem* parent, const TQString& name, NicksOnlineItem::NickListViewColumn type);
/**
* Returns the first occurrence of a child item of a given type in a NicksOnlineItem
* @param tqparent Pointer to a NicksOnlineItem.
* @param type The type of entry to be found
* @return Pointer to the child TQListViewItem or 0 if not found.
*/
- TQListViewItem* findItemType(const TQListViewItem* tqparent, NicksOnlineItem::NickListViewColumn type);
+ TQListViewItem* findItemType(const TQListViewItem* parent, NicksOnlineItem::NickListViewColumn type);
/**
* Returns a pointer to the network TQListViewItem with the given name.
* @param name The name of the network, assumed to be in column 0 of the item.
@@ -135,20 +135,20 @@ class NicksOnline : public ChatWindow
private:
/**
- * Returns the named child of tqparent item in a NicksOnlineItem
- * @param tqparent Pointer to a NicksOnlineItem.
+ * Returns the named child of parent item in a NicksOnlineItem
+ * @param parent Pointer to a NicksOnlineItem.
* @param name The name in the desired child TQListViewItem, must be in column 0.
* @param type The type of entry to be found
@@ -135,20 +135,20 @@ class NicksOnline : public ChatWindow
/**
* Returns the first occurrence of a child item of a given type in a NicksOnlineItem
- * @param tqparent Pointer to a NicksOnlineItem.
+ * @param parent Pointer to a NicksOnlineItem.
* @param type The type of entry to be found
* @return Pointer to the child TQListViewItem or 0 if not found.